from setuptools import setup

setup(name='robberslang',
	version='0.1',
	description='String to robbers lang',
	url='http://bit.ly/1WJ6b77',
	author='Ivar Matstoms',
	author_email='ivar.matstoms@gmail.com',
	license='GPL',
	scripts=['bin/robberslang'],
	zip_safe=False)
